#!/usr/bin/python

"Make graphs from json data files."

from datetime import datetime
from glob import glob
from os.path import (
    abspath,
    dirname,
    exists,
    join,
    )
from os import listdir
import json
from matplotlib import pyplot

TEST_DATA = {}

def main():
    base_path = get_base_dir()
    results_dir = join(base_path, 'results')
    for date_time_string in listdir(results_dir):
        dt = datetime.strptime(date_time_string, "%Y-%m-%d_%H-%M-%S")
        for machine_config in listdir(join(results_dir, date_time_string)):
            result_path = join(
                results_dir,
                date_time_string,
                machine_config,
                'results.json')
            if not exists(result_path):
                print "Error: no results at path: %s" % result_path
                continue
            data = json.load(open(result_path))
            tests = data.get('Test Data')
            for test_name in tests.iterkeys():
                if test_name not in TEST_DATA:
                    TEST_DATA[test_name] = {}
                if machine_config not in TEST_DATA[test_name]:
                    TEST_DATA[test_name][machine_config] = [[],[]]
                TEST_DATA[test_name][machine_config][0].append(dt)
                TEST_DATA[test_name][machine_config][1].append(tests[test_name]['FPS'])
    for test_name in TEST_DATA.iterkeys():
        pyplot.close('all')
        for machine_config in TEST_DATA[test_name]:
            # import pdb; pdb.set_trace()
            test_data = zip(
                TEST_DATA[test_name][machine_config][0],
                TEST_DATA[test_name][machine_config][1]
                )
            test_data = sorted(test_data, key=lambda a: a[0])
            x_axis, y_axis = zip(*test_data)
            pyplot.plot_date(
                x_axis,
                y_axis,
                'o-',
                label=machine_config,
                )
        pyplot.xlabel('date')
        pyplot.ylabel('FPS')
        pyplot.ylim(ymin=0)
        pyplot.title(test_name)
        pyplot.legend(
            fancybox=True,
            # bbox_to_anchor=(1.05, 0.5),
            loc=4,
            # borderaxespad=0.
            )
        pyplot.savefig(test_name + '.png')

    with open('index.html','w') as f:
        f.write('<html><body>')
        f.write('<h1>Mir Display Server Benchmark Graphs</h1>')
        for img in glob('*.png'):
            f.write('<img src="%s" />' % (img))
        f.write('</body></html>')





def get_base_dir():
    return abspath(dirname(__file__))

if __name__ == '__main__':
    main()
